import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { useMemo, useCallback } from 'react';
import { Box, Text, Button, Checkbox } from '@chakra-ui/react';
import Table, { useRowSelection } from 'react-data-grid';
import { useLape, ignoreState } from 'lape';

const SELECT_HEADER_TITLE = "Select header row";
const CANCEL_BUTTON_TITLE = "Cancel";
const CONFIRM_BUTTON_TITLE = "Confirm and continue";
const NO_SELECTION_ERROR = "Header row not selected";
const TableCheckbox = (props) => {
    const [isRowSelected, onRowSelectionChange] = useRowSelection();
    return (jsx(Box, { h: "100%", display: "flex", alignItems: "center", children: jsx(Checkbox, { isChecked: isRowSelected, onChange: (e) => {
                onRowSelectionChange({
                    row: props.row,
                    checked: e.target.checked,
                    isShiftClick: e.nativeEvent.shiftKey,
                });
            } }, void 0) }, void 0));
};
const SelectHeader = ({ data, onCancel, onContinue }) => {
    const state = useLape({
        selectedRow: ignoreState(new Set()),
    });
    const rowLength = useMemo(() => Math.max(...data.map((row) => row.length)), [data]);
    const columns = useMemo(() => [
        {
            key: "cx",
            name: "cx",
            formatter: TableCheckbox,
            maxWidth: 40,
            width: 40,
        },
        ...Array.from({ length: rowLength }).map((_, index) => ({
            key: index + "",
            name: index + "",
            resizable: true,
        })),
    ], [rowLength]);
    const rowKeyGetter = useCallback((row) => row, []);
    const handleContinue = useCallback(() => {
        const [selectedRow] = state.selectedRow;
        if (!selectedRow) {
            state.error = NO_SELECTION_ERROR;
            return;
        }
        // We consider data above header to be redundant
        const headerIndex = data.findIndex((row) => row === selectedRow);
        const trimmedData = data.slice(headerIndex + 1);
        onContinue(selectedRow, trimmedData);
    }, [onContinue, data]);
    return (jsxs(Fragment, { children: [jsxs(Box, { minH: "5.375rem", display: "flex", alignItems: "center", px: "0.75rem", children: [jsx(Text, { variant: "h5", mr: "1rem", pb: 1, children: SELECT_HEADER_TITLE }, void 0), jsxs(Box, { display: "flex", flex: 1, justifyContent: "flex-end", children: [jsx(Button, { variant: "outline", mr: "1rem", onClick: onCancel, children: CANCEL_BUTTON_TITLE }, void 0), jsx(Button, { onClick: handleContinue, children: CONFIRM_BUTTON_TITLE }, void 0)] }, void 0)] }, void 0), state.error && (jsx(Text, { color: "error.500", px: "0.75rem", pb: "0.75rem", children: state.error }, void 0)), jsx(Box, { display: "flex", flex: 1, px: 1, pb: "2rem", children: jsx(Table, { rowKeyGetter: rowKeyGetter, rows: data, columns: columns, headerRowHeight: 0, selectedRows: state.selectedRow, onSelectedRowsChange: (rows) => {
                        state.error = undefined;
                        const size = rows.size;
                        if (size === 1) {
                            state.selectedRow = ignoreState(rows);
                        }
                        else {
                            const [_, newItem] = rows;
                            // react-data-grid only accepts Sets
                            state.selectedRow = ignoreState(new Set([newItem]));
                        }
                    }, className: "rdg-static" }, void 0) }, void 0)] }, void 0));
};

export { SelectHeader };
