import { jsx } from 'react/jsx-runtime';
import { Upload } from './Upload.js';
import { SelectHeader } from './SelectHeader.js';
import { MatchColumns } from './MatchColumns.js';
import { useState } from 'react';
import { Progress } from '@chakra-ui/react';

var Type;
(function (Type) {
    Type[Type["upload"] = 0] = "upload";
    Type[Type["selectHeader"] = 1] = "selectHeader";
    Type[Type["loadMatchColumns"] = 2] = "loadMatchColumns";
    Type[Type["loadMatchColumnsError"] = 3] = "loadMatchColumnsError";
    Type[Type["matchColumns"] = 4] = "matchColumns";
    Type[Type["submitMatchColumns"] = 5] = "submitMatchColumns";
    Type[Type["submitMatchColumnsError"] = 6] = "submitMatchColumnsError";
})(Type || (Type = {}));
const UploadFlow = ({ config }) => {
    const [state, setState] = useState({ type: Type.upload });
    switch (state.type) {
        case Type.upload:
            return (jsx(Upload, { onContinue: (data) => {
                    setState({ type: Type.selectHeader, data });
                } }, void 0));
        case Type.selectHeader:
            return (jsx(SelectHeader, { data: state.data, onContinue: (headerValues, data) => {
                    setState({
                        type: Type.loadMatchColumns,
                        headerValues,
                        data,
                    });
                }, onCancel: () => {
                    setState({ type: Type.upload });
                } }, void 0));
        case Type.matchColumns:
        case Type.submitMatchColumns:
        case Type.submitMatchColumnsError:
            return (jsx(MatchColumns, { headerValues: state.headerValues, onCancel: () => {
                    setState({ type: Type.upload });
                }, values: state.values, table: state.table, loading: state.type === Type.submitMatchColumns, error: state.type === Type.submitMatchColumnsError ? state.error : undefined, onContinue: (values) => {
                    if (state.type === Type.matchColumns || state.type === Type.submitMatchColumnsError) {
                        setState({
                            type: Type.submitMatchColumns,
                            data: state.data,
                            headerValues: state.headerValues,
                            table: state.table,
                            values,
                        });
                    }
                } }, void 0));
        case Type.loadMatchColumns:
            return jsx(Progress, { isIndeterminate: true }, void 0);
        default:
            return null;
    }
};

export { UploadFlow };
